<?php

/**
 * The settings of the plugin.
 *
 * @link       http://profile.wordpress.org/apsaraaruna
 * @since      1.0.0
 *
 * @package    Easy_Full_Screen_Search
 * @subpackage Easy_Full_Screen_Search/includes
 */

/**
 * Class WordPress_Plugin_Template_Settings
 *
 */
class Easy_Full_Screen_Search_Admin_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}


	public function setup_plugin_options_menu() {

		add_submenu_page(
			"options-general.php",
			'Easy Search', 	
			'Easy Search',	
			'manage_options',
			'easy_search_options',
			array( $this, 'render_settings_page_content')
		);

	}


	public function default_about_options() {

	}
	public function default_display_options() {

		$defaults = array(
			'enable_bsb'		=>	'',
			'efssf_close_btn_padding_x'		=>	'20',
			'efssf_close_btn_padding_y'		=>	'10',
		);

		return $defaults;

	}

	public function render_settings_page_content( $active_tab = '' ) {
		?>
		<div class="wrap">

			<h2><?php _e( 'Eazy Search Option', 'easy-full-screen-search-form' ); ?></h2>
			<?php settings_errors(); ?>

			<?php if( isset( $_GET[ 'tab' ] ) ) {
				$active_tab = $_GET[ 'tab' ];
			} else if( $active_tab == 'efssf_about' ) {
				$active_tab = 'efssf_about';
			} else if( $active_tab == 'input_examples' ) {
				$active_tab = 'input_examples';
			} else {
				$active_tab = 'display_options';
			} // end if/else ?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=easy_search_options&tab=display_options" class="nav-tab <?php echo $active_tab == 'display_options' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Display Options', 'easy-full-screen-search-form' ); ?></a>
				<a href="?page=easy_search_options&tab=efssf_about" class="nav-tab <?php echo $active_tab == 'efssf_about' ? 'nav-tab-active' : ''; ?>"><?php _e( 'About', 'easy-full-screen-search-form' ); ?></a>
			</h2>

			<form method="post" action="options.php">
				<?php

				if( $active_tab == 'display_options' ) {

					settings_fields( 'efssf_display_options' );
					do_settings_sections( 'efssf_display_options' );
					submit_button();

				} elseif( $active_tab == 'efssf_about' ) {

					settings_fields( 'efssf_about_options' );
					do_settings_sections( 'efssf_about_options' );

				} else {

					// settings_fields( 'aspye_option_input_examples' );
					// do_settings_sections( 'aspye_option_input_examples' );

				} 

				

				?>
			</form>

		</div>
		<?php
	}


	public function general_options_callback() {
		$options = get_option('efssf_display_options');
		echo '<p>' . __( 'Select which areas of content you wish to display.', 'easy-full-screen-search-form' ) . '</p>';
	} 

	public function initialize_about_options() {
		if( false == get_option( 'efssf_about_options' ) ) {
			$default_array = $this->default_about_options();
			update_option( 'efssf_about_options', $default_array );
		} 

		add_settings_section(
			'social_settings_section',	
			__( 'You may also like this plugin', 'easy-full-screen-search-form' ),
			array( $this, 'about_options_callback'),
			'efssf_about_options'
		);

	}
	public function about_options_callback() {
		$options = get_option('efssf_about_options');
		echo '
		<p> <a href="https://wordpress.org/plugins/widget-youtube-subscribtion/" target="_blank">Easy Subscribe Button Widget >></a></p>
		<p> <a href="https://wordpress.org/plugins/popup-notification-news-alert/" target="_blank">Toast Popup Notification News Alert >></a></p>
		<p> <a href="https://wordpress.org/plugins/embed-page-facebook/" target="_blank">Easy Embed Page Widget >></a></p>
		<p> <a href="https://wordpress.org/plugins/browser-scroll-bar/" target="_blank">Browser Scroll Bar >></a></p>

		';
	}

	public function initialize_display_options() {

		if( false == get_option( 'efssf_display_options' ) ) {
			$default_array = $this->default_display_options();
			add_option( 'efssf_display_options', $default_array );
		}


		add_settings_section(
			'general_settings_section',	
			__( 'Display Options', 'easy-full-screen-search-form' ),
			array( $this, 'general_options_callback'),
			'efssf_display_options'	
		);

		add_settings_field(
			'show_header',	
			__( 'Search Box', 'easy-full-screen-search-form' ),	
			array( $this, 'toggle_header_callback'),
			'efssf_display_options',
			'general_settings_section'
		);

		add_settings_field(
			'show_content',
			__( 'Input field text', 'easy-full-screen-search-form' ),
			array( $this, 'toggle_content_callback'),
			'efssf_display_options',
			'general_settings_section'
		);

		add_settings_field(
			'show_footer',
			__( 'Search button', 'easy-full-screen-search-form' ),
			array( $this, 'toggle_footer_callback'),
			'efssf_display_options',
			'general_settings_section'
		);

		add_settings_field(
			'show_close_button',
			__( 'Close button', 'easy-full-screen-search-form' ),
			array( $this, 'toggle_close_button_callback'),
			'efssf_display_options',
			'general_settings_section'
		);

		register_setting(
			'efssf_display_options',
			'efssf_display_options'
		);

	} 


	public function toggle_header_callback($args) {

		$options = get_option('efssf_display_options');

		$html = '<div><input type="text"  id="search_wrapper_bg" name="efssf_display_options[search_wrapper_bg]" class="color-picker" data-alpha="true" data-default-color="rgba(0,0,0,0.85)" value="' . sanitize_text_field($options['search_wrapper_bg']) . '" /> <small>Background color</small></div>';


		echo $html;

	} 
	
	public function toggle_content_callback($args) {

		$options = get_option('efssf_display_options');

		echo '<input type="text" id="efssf_input" name="efssf_display_options[efssf_input]" value="' . $options['efssf_input'] . '" />';

	} 

	public function toggle_footer_callback($args) {

		$options = get_option('efssf_display_options');

		echo '<div>
		<input type="text" id="efssf_btn_text" name="efssf_display_options[efssf_btn_text]" value="' . $options['efssf_btn_text'] . '" />
		</div>
		<div><p><input type="text"  id="efssf_btn_color" name="efssf_display_options[efssf_btn_color]" class="color-picker" data-alpha="false" data-default-color="#333333" value="' . sanitize_text_field($options['efssf_btn_color']) . '" /> <small>Background color</small></p></div>
		<div><p><input type="text" id="efssf_btn_padding_y" name="efssf_display_options[efssf_btn_padding_y]" value="' . $options['efssf_btn_padding_y'] . '" /><input type="text" id="efssf_btn_padding_x" name="efssf_display_options[efssf_btn_padding_x]" value="' . $options['efssf_btn_padding_x'] . '" /></p>
		<small>Button padding y and x</small>
		</div>
		';

	} 

	public function toggle_close_button_callback($args){
		$options = get_option('efssf_display_options');

		echo '
		<div><p><input type="text"  id="efssf_close_btn_color" name="efssf_display_options[efssf_close_btn_color]" class="color-picker" data-alpha="false" data-default-color="#333333" value="' . sanitize_text_field($options['efssf_close_btn_color']) . '" /> <small>Background color</small></p></div>
		<div><p><input type="number" id="efssf_close_btn_padding_y" name="efssf_display_options[efssf_close_btn_padding_y]" value="' . $options['efssf_close_btn_padding_y'] . '" /><input type="number" id="efssf_close_btn_padding_x" name="efssf_display_options[efssf_close_btn_padding_x]" value="' . $options['efssf_close_btn_padding_x'] . '" /></p><small>Button padding y and x</small></div>
		';
	}


	public function eazy_fullscreen_search_form( $form ) {
		$options = get_option('efssf_display_options');

		$form = '<div id="efss-form">';
		$form .= '<button type="button" class="close">×</button>';
		$form .= '<form role="search" method="get" id="searchform" action="'.esc_url( home_url( '/' ) ).'" >';
		$form .= '<input type="text" value="'. get_search_query().'" name="s" id="s" placeholder="'.$options["efssf_input"].'" autocomplete="off" />';
		$form .= '<button type="submit" id="searchsubmit" class="btn btn-blk" value="'. esc_attr_x( 'Search', 'submit button' ).'">'.$options["efssf_btn_text"].'</button>';
		$form .= '</form>';
		$form .= '</div>';
		return $form;
	}

	public function eazy_fullscreen_search_form_style(){
		$options = get_option('efssf_display_options');
		?>
		<style type="text/css">
			#efss-form {
				position: fixed;
				top: 0px;
				left: 0px;
				width: 100%;
				height: 100%;
				background-color: <?php echo $options["search_wrapper_bg"] ?>;
				-webkit-transition: all 0.5s ease-in-out;
				-moz-transition: all 0.5s ease-in-out;
				-o-transition: all 0.5s ease-in-out;
				-ms-transition: all 0.5s ease-in-out;
				transition: all 0.5s ease-in-out;
				-webkit-transform: translate(0px, -100%) scale(0, 0);
				-moz-transform: translate(0px, -100%) scale(0, 0);
				-o-transform: translate(0px, -100%) scale(0, 0);
				-ms-transform: translate(0px, -100%) scale(0, 0);
				transform: translate(0px, -100%) scale(0, 0);
				opacity: 0;
				z-index: 99;
			}
			#efss-form form#searchform {
				height: 100%;
			}

			#efss-form input[type="text"] {
				position: absolute;
				top: 50%;
				width: 100%;
				color: white;
				background: rgba(0, 0, 0, 0);
				font-size: 60px;
				font-weight: 300;
				text-align: center;
				border: 0px;
				margin: 0px auto;
				margin-top: -51px;
				padding-left: 30px;
				padding-right: 30px;
				outline: none;
			}
			#efss-form .btn {
				position: relative;
				top: 58%;
				background-color: <?php echo $options['efssf_btn_color'] ?>;
				border: black;
				color: #fff;
				padding: <?php echo $options['efssf_btn_padding_y'].'px ' . $options['efssf_btn_padding_x'].'px' ?>;
				margin: 0 auto;
				display: block;
				font-size: 20px;
			}
			#efss-form .btn:hover {
				cursor: pointer;
			}
			#efss-form .close {
				position: fixed;
				top: 15px;
				right: 15px;
				color: #fff;
				background-color: <?php echo $options['efssf_close_btn_color'] ?>;
				border-color: <?php echo $options['efssf_close_btn_color'] ?>;
				opacity: 1;
				padding: <?php echo $options['efssf_close_btn_padding_y'].'px ' . $options['efssf_close_btn_padding_x'].'px' ?>;
				font-size: 27px;
			}
			#efss-form.open {
				-webkit-transform: translate(0px, 0px) scale(1, 1);
				-moz-transform: translate(0px, 0px) scale(1, 1);
				-o-transform: translate(0px, 0px) scale(1, 1);
				-ms-transform: translate(0px, 0px) scale(1, 1);
				transform: translate(0px, 0px) scale(1, 1);
				opacity: 1;
			}
		</style>

		<?php
	}


}